﻿"use strict";

var REFIND589 = {
	AIR: 1.000292,
	WATER: 1.3324,
	MgF2: 1.3777,
	LiF: 1.3921,
	SILICA: 1.4584,
	PMMA: 1.491,
	BK7: 1.5167,
	SODALIME: 1.5233,
	NaCl: 1.5441,
	POLYCARB: 1.585,
	POLYSTYR: 1.592,
	F2: 1.6199,
	CS2: 1.6275,
	SAPPHIRE: 1.7681,
	YSZ: 2.1585,
	DIAMOND: 2.4166,
	RUTILE: 2.6128,
	SILICON: 3.9715
};

function Sellmeier(B, C) {
	return function(x) {
		x = x * x;
		var res = 1;
		for (var i = 0; i < B.length; i++)
			res += B[i] * x / (x - C[i]);
			
		return Math.sqrt(res);
	};
}


var DISPERS = {
	BK7: {
		min: 0.3,
		max: 2.5,
		dispers: Sellmeier([1.03961212, 0.231792344, 1.01046945], [6.00069867e-3, 2.00179144e-2, 103.560653])
	},
	
	SILICA: {
		min: 0.21,
		max: 6.7,
		dispers: Sellmeier([0.6961663, 0.4079426, 0.8974794], [4.67914826e-3, 1.35120631e-2, 97.9340025])
	},
	
	MgF2: {
		min: 0.2,
		max: 7.0,
		dispers: Sellmeier([0.48755108, 0.39875031, 2.3120353], [0.001882178, 0.008951888, 566.13559])
	},
	
	SAPPHIRE: {
		min: 0.2,
		max: 5.0,
		dispers: Sellmeier([1.4313493, 0.65054713, 5.3414021], [5.2799261e-3, 1.42382647e-2, 325.017834])
	},
	
	PMMA: {
		min: 0.43,
		max: 1.06,
		dispers: Sellmeier([1.1819], [0.011313])
	},
	
	CS2: {
		min: 0.5,
		max: 1.6,
		dispers: Sellmeier([1.50387], [0.03049])
	},
	
	ZNO: {
		min: 0.4,
		max: 3.2,
		dispers: Sellmeier([1.975705, 0.00473], [0.031641, 0.151175])
	},
	
	DIAMOND: {
		min: 0.2,
		max: 0.8,
		dispers: Sellmeier([0.3306, 4.3356], [0.030625, 0.011236])
	},
	
	RUTILE: {
		min: 0.43,
		max: 1.53,
		dispers: function(x) { return Math.sqrt(5.913 + 0.2441 / (x*x - 0.0803)); }
	},
	
	WATER: {
		min: 0.182,
		max: 1.129,
		dispers: Sellmeier([5.666959820e-1, 1.731900098e-1, 2.095951857e-2, 1.125228406e-1], [5.084151894e-3, 1.818488474e-2, 2.625439472e-2, 10.73842352])
	},
	
	REFLECTIVE: {
		min: 0.2,
		max: 2,
		dispers: Math.constant(-1)
	}
};

function showDispers(item) {
	var material = item.getObj();
	var wave = Array.linspace(Math.max(material.min, 0.3), Math.min(material.max, 0.9), TRACE_POINTS);
	var ridx = wave.map(material.dispers);
	
	var info = {
		x: wave.map(Multiplier(1e3)),
		y: ridx,
		xtitle: 'Lainepikkus (nm)',
		ytitle: 'Murdumisnäitaja',
		title: item.toString(),
		xfmt: '.1f',
		yfmt: '.4f'
	};

	showGraph({width: 750, height: 450}, info)
}