﻿"use strict";

var I18N = (function(){
	var toolbar = null;
	var dict = null;
	var lang = null; // active language
	var other = [];  // other supported languages

	var std = {
		'et-en': {
			'Apertuur': 'Aperture',
			'hall': 'grey',
			'katseskeem': 'scheme',
			'Kile paksus': 'Film thickness',
			'Kontrast': 'Contrast',
			'kroonklaas': 'crown glass',
			'kuum': 'hot',
			'kvartsklaas': 'fused silica',
			'külm': 'cold',
			'Lainepikkus': 'Wavelength',
			'Langemisnurk': 'Incidence angle',
			'Murdumisnäitaja': 'Refractive index',
			'Nurk': 'Angle',
			'Paksus': 'Thickness',
			'Peegeldustegur': 'Reflectance',
			'Pilu laius': 'Slit width',
			'rutiil': 'rutile',
			'räni': 'silicon',
			'safiir': 'sapphire',
			'sooda-lubi-liivklaas': 'soda–lime glass',
			'Stsenaarium': 'Preset',
			'teemant': 'diamond',
			'Vaateväli': 'Field of view',
			'Valgusallikas': 'Light source',
			'vesi': 'water',
			'Värviskaala': 'Colormap',
			'õhk': 'air'
		}
	};
	
	var params = parseKeyValuePairs(location.search.substring(1));
	if ('lang' in params)
		lang = params.lang;

	function translate(text) {
		return dict && text in dict ? dict[text] : text;
	}

	translate.dict = function(id, dictionary) {
		if (lang && id === lang) {
			if (dict)
				Object.assign(dict, dictionary);
			else
				dict = dictionary;
		}
	};

	translate.activate = function(languages, deflang) {
		if (toolbar)
			return;
			
		if (deflang === undefined)
			deflang = languages[0];
	
		if (!lang)
			lang = deflang;
		else
		{
			var key = deflang + '-' + lang;
			if (key in std)
				dict = std[key];
		}
	
		toolbar = document.createElement('div');
		toolbar.className = 'i18n';
		var url = location.protocol + '//' + location.host + location.pathname;
		
		languages.forEach(function(id) {
			if (id === lang)
				return;
		
			other.push(id);
		
			var img = document.createElement('img');
			img.src = 'icons/' + id + '.svg';
			if (id === deflang)
				img.onclick = function() { location.href = url; };
			else
				img.onclick = function() { location.href = url + '?lang=' + id; };
			toolbar.appendChild(img);
		});
		
		document.body.appendChild(toolbar);
	};
	
	translate.show = translate.activate;
	
	translate.title = function(id, title) {
		if (lang && id === lang) {
			document.title = title;
			var e = document.getElementById("pagetitle");
			if (e)
				e.innerHTML = title;
		}
	};

	translate.elements = function() {
		other.forEach(function(item){
			var elems = document.querySelectorAll('[lang="' + item + '"]');
			for (var i = 0; i < elems.length; i++)
				elems[i].style.display = 'none';
		});
	
		if (!dict)
			return;
	
		var list = document.getElementsByClassName('translate');
		for (var i = 0; i < list.length; i++) {
			var e = list[i];
			var t = e.innerHTML;
			if (t in dict)
				e.innerHTML = dict[t];
		}
	};

	translate.lang = function() {
		return lang;
	};

	return translate;
})();

