﻿"use strict";

function Vector(x, y) {
	this.x = x;
	this.y = y;
}

Vector.polar = function(len, angle) {
	return new Vector(len * Math.cos(angle), len * Math.sin(angle));
};

Vector.prototype.length = function() {
	return Math.sqrt(this.x * this.x + this.y * this.y);
};

Vector.prototype.angle = function() {
	return Math.atan2(this.y, this.x);
};

Vector.prototype.unit = function() {
	var len = this.length();
	return new Vector(this.x / len, this.y / len);
};

Vector.prototype.dot = function(vector) {
	return this.x * vector.x + this.y * vector.y;
};

Vector.prototype.reverse = function() {
	return new Vector(-this.x, -this.y);
};

Vector.prototype.perp = function() {
	return new Vector(this.y, -this.x);
};

Vector.prototype.translate = function(dx, dy) {
	return new Vector(this.x + dx, this.y + dy);
};

Vector.prototype.rotate = function(angle) {
	var sin = Math.sin(angle);
	var cos = Math.cos(angle);
	
	return new Vector(
		this.x * cos - this.y * sin,
		this.x * sin + this.y * cos
	);
};

Vector.prototype.mul = function(factor) {
	return new Vector(factor * this.x, factor * this.y);
};

Vector.prototype.div = function(factor) {
	return new Vector(this.x / factor, this.y / factor);
};

Vector.prototype.add = function(vector) {
	return new Vector(this.x + vector.x, this.y + vector.y);
};

Vector.prototype.sub = function(vector) {
	return new Vector(this.x - vector.x, this.y - vector.y);
};

Vector.prototype.refract = function(v_n, ridx) {
	var u_n = v_n.unit();
	var u_t = u_n.perp();
	var u_r = this.unit();
	if (u_n.dot(u_r) < 0)
		u_n = u_n.reverse();
	
	var sin = u_r.dot(u_t);
	var cos;
	var trans;
	if (Math.abs(sin) >= ridx) {
		cos = -Math.sqrt(1 - sin * sin);
		trans = false;
	} else {
		sin /= ridx;
		cos = Math.sqrt(1 - sin * sin);
		trans = true;
	}
		
	return {
		dir: new Vector(  // new direction
			sin * u_t.x + cos * u_n.x,
			sin * u_t.y + cos * u_n.y
		),
		
		trans: trans  // transmitted ?
	};
};

Vector.prototype.toString = function() {
	return '(' + this.x.toString() + ', ' + this.y.toString() + ')';
};
